@@ -13,23 +13,26 @@ has marc_path  => (fix_arg => 1);
 has value      => (fix_arg => 1);
 
 sub emit {
-	my ($self,$fixer,$label) = @_;
+    my ($self,$fixer,$label) = @_;
 
-	my $perl;
+    my $perl;
 
-	my $tmp_var  = '_tmp_' . int(rand(9999));
-	my $marc_map = Catmandu::Fix::marc_map->new($self->marc_path , "$tmp_var.\$append");
-	$perl .= $marc_map->emit($fixer,$label);
+    my $tmp_var  = '_tmp_' . int(rand(9999));
+    my $marc_map = Catmandu::Fix::marc_map->new($self->marc_path , "$tmp_var.\$append");
+    $perl .= $marc_map->emit($fixer,$label);
 
-	my $all_match = Catmandu::Fix::Condition::all_match->new("$tmp_var.*",$self->value);
-	$all_match->pass_fixes($self->pass_fixes);
-	$all_match->fail_fixes($self->fail_fixes);
-	$perl .= $all_match->emit($fixer,$label);  
+    my $all_match = Catmandu::Fix::Condition::all_match->new("$tmp_var.*",$self->value);
+    my $remove_field = Catmandu::Fix::remove_field->new($tmp_var);
 
-	my $remove_field = Catmandu::Fix::remove_field->new($tmp_var);
-	$perl .= $remove_field->emit($fixer,$label);
+    my $pass_fixes = $self->pass_fixes;
+    my $fail_fixes = $self->fail_fixes;
 
-	$perl;
+    $all_match->pass_fixes([ $remove_field , @$pass_fixes ]);
+    $all_match->fail_fixes([ $remove_field , @$fail_fixes ]);
+
+    $perl .= $all_match->emit($fixer,$label);
+
+    $perl;
 }
 
 =head1 NAME
